#### A Utility for Sys Admin or Personal Use (Intergrated with SHELL).

__TODO__ to integrate with ORM relational databases.


### Installation (any platform)
```
$ python3 -m pip install --no-cache-dir --upgrade py-laxz
```

### Usage (as script)
```
$ pylaxz --help # for options
$ pylaxz -N --help # for Network options
$ pylaxz -S --help # for System options
$ pylaxz -L --help # for SHELL options
```

### Rare Usage (as direct)
```
$ python3 -m pylaxz -h
```

### Usage (as python module - logxs for machine learning)
```
>>> from pylaxz.utils.logxs import printf
>>> printf(ANYTHING)
```

if you have time : 

``` 
>>> import pylaxz
>>> dir(pylaxz)
>>> help(pylaxz)
```

+ printf is logger function and works well with various python's data types
+ and also with numpy's data shapes.
